@@ -33,7 +33,7 @@ class App(object):
         if title is None:
             title=version.description
         self.title=title
-        self.menu=""
+        self.menu={}
         self.websockets=websockets
         
     def mainInstance(self,argv=None,callback=None): # IGNORE:C0111
@@ -60,8 +60,6 @@ class App(object):
         parser.add_argument('-V', '--version', action='version', version=self.version.longDescription)
         return parser
     
-    def getMenu(self):
-        return self.menu
     
     def pageHtml(self,level):
         '''
@@ -84,10 +82,13 @@ class App(object):
         elif level=="body":
             html="""<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.2.0/dist/js/bootstrap.bundle.min.js" integrity="sha384-A3rJD856KowSb7dwlZdYEkO39Gagi7vIsF0jrRAoQmDKKtQBHUuLZ9AsSv4jD4Xa" crossorigin="anonymous"></script>"""
         elif level == "container":
+            menuHtml=""
+            for menuEntry in self.menu.values():
+                menuHtml+=menuEntry.asHtml()
             html=f"""<div name='containerbox'>
         <!--  common menu -->
 <div name='headerbox' id='headerbox'>
-{self.menu}
+{menuHtml}
 </div>
         <div name="navigationbox" id="navigationbox" title="{self.title}">{self.title}</div>
         <div name="contentbox" class="container-fluid" id="contentbox">
@@ -199,22 +200,38 @@ class App(object):
             sys.stderr.write(indent + "  for help use --help")
             return 2
         
-    def addMenuLink(self,text,icon,href):
+    def addMenuLink(self,text,icon,href,target=None):
         '''
          add a menu entry
          
          text(str)
          icon(str): see https://materialdesignicons.com/ for possible icons
          href(str): the link
+         target(str): "_blank" or None
         '''
-        self.menu+=f"""
-  <!-- {text} --><a
-    href='{href}'
-    title='{text}'>
-    <i class='mdi mdi-{icon} headerboxicon'></i>
-  </a>
-"""        
+        self.menu[text]=MenuEntry(text,icon,href,target)
 
+class MenuEntry:
+    '''
+    a menu entry
+    '''
+    def __init__(self,text,icon,href,target):
+        self.text=text
+        self.icon=icon
+        self.href=href
+        self.target=target
+        
+    def asHtml(self):
+        target="" if self.target is None else f" target=' {self.target}'"
+        html=f"""
+  <!-- {self.text} --><a
+    href='{self.href}'
+    title='{self.text}'{target}>
+    <i class='mdi mdi-{self.icon} headerboxicon'></i>
+  </a>
+"""   
+        return html     
+        
 class Link:
     '''
     a link
@@ -344,27 +361,25 @@ class Collapsible(jp.Div):
     """
     Collapsible div
     see https://getbootstrap.com/docs/4.0/components/collapse/
-    """
-    CHEVRON_DOWN = """<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-chevron-down" viewBox="0 0 16 16">
-  <path fill-rule="evenodd" d="M1.646 4.646a.5.5 0 0 1 .708 0L8 10.293l5.646-5.647a.5.5 0 0 1 .708.708l-6 6a.5.5 0 0 1-.708 0l-6-6a.5.5 0 0 1 0-.708z"/>
-</svg>"""
 
-    CHEVRON_RIGHT = """<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-chevron-right" viewBox="0 0 16 16">
-  <path fill-rule="evenodd" d="M4.646 1.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1 0 .708l-6 6a.5.5 0 0 1-.708-.708L10.293 8 4.646 2.354a.5.5 0 0 1 0-.708z"/>
-</svg>"""
+    use the body attribute to assign contents to the collapsible body
+    """
 
     def __init__(self, label:str, collapsed:bool=False, **kwargs):
         '''
         constructor
         '''
-        super().__init__(**kwargs)
+        super().__init__(classes="accordion", **kwargs)
+        self.div = jp.Div(a=self, classes="accordion-item")
         self.label = label
-        self.btnClasses = "btn btn-secondary d-inline-flex align-items-center rounded"
-        self.btn = jp.Button(a=self,
-                             inner_html=f"{self.CHEVRON_DOWN}\n{self.label}",
+        self.btnClasses = "accordion-button"
+        self.bodyClasses = "accordion-collapse"
+        self.btn = jp.Button(a=self.div,
+                             inner_html=self.label,
                              classes=self.btnClasses,
                              click=self.collapse)
-        self.body = jp.Div(a=self, classes="collapse show")
+        self.collapsibleDiv = jp.Div(a=self.div, classes=f"{self.bodyClasses} collapse show")
+        self.body = jp.Div(a=self.collapsibleDiv, classes=f"accordion-body collapse show")
         self.collapsed=collapsed
         self.collapse(changeState=True)
 
@@ -373,11 +388,11 @@ class Collapsible(jp.Div):
         change state of Collapsible body
         """
         if self.collapsed:
-            self.btn.inner_html=f"{self.CHEVRON_DOWN}\n{self.label}"
-            self.body.classes="collapse show"
+            self.btn.classes = f"{self.btnClasses}"
+            self.collapsibleDiv.classes=f"{self.bodyClasses} collapse show"
         else:
-            self.btn.inner_html=f"{self.CHEVRON_RIGHT}\n{self.label}"
-            self.body.classes="collapse"
+            self.btn.classes = f"{self.btnClasses} collapsed"
+            self.collapsibleDiv.classes = f"{self.bodyClasses} collapse"
         if changeState:
             self.collapsed = not self.collapsed
 
